pub struct KubelintConfig {
pub add_all_builtin: bool,
pub do_not_auto_add_defaults: bool,
pub include: Vec<String>,
pub exclude: Vec<String>,
pub ignore_paths: Vec<String>,
pub custom_checks: Vec<CheckSpec>,
pub failure_threshold: Severity,
pub no_fail: bool,
}Expand description
Configuration for the KubeLint linter.
Fields
add_all_builtin: boolIf true, add all built-in checks regardless of defaults.
do_not_auto_add_defaults: boolIf true, do not automatically add default checks.
include: Vec<String>List of check names to include (in addition to defaults).
exclude: Vec<String>List of check names to exclude.
ignore_paths: Vec<String>Glob patterns for paths to ignore.
custom_checks: Vec<CheckSpec>Custom check definitions.
failure_threshold: SeverityMinimum severity to report. Checks below this threshold are filtered.
no_fail: boolIf true, never return a non-zero exit code.
Implementations
Sourceimpl KubelintConfig
impl KubelintConfig
Sourcepub fn ignore_path(self, pattern: impl Into<String>) -> Self
pub fn ignore_path(self, pattern: impl Into<String>) -> Self
Add a path pattern to ignore.
Sourcepub fn with_threshold(self, threshold: Severity) -> Self
pub fn with_threshold(self, threshold: Severity) -> Self
Set the failure threshold.
Sourcepub fn with_all_builtin(self) -> Self
pub fn with_all_builtin(self) -> Self
Enable all built-in checks.
Sourcepub fn without_defaults(self) -> Self
pub fn without_defaults(self) -> Self
Disable automatic default checks.
Sourcepub fn is_check_excluded(&self, check_name: &str) -> bool
pub fn is_check_excluded(&self, check_name: &str) -> bool
Check if a check is explicitly excluded.
Sourcepub fn is_check_included(&self, check_name: &str) -> bool
pub fn is_check_included(&self, check_name: &str) -> bool
Check if a check is explicitly included.
Sourcepub fn resolve_checks<'a>(
&self,
available: &'a [CheckSpec],
) -> Vec<&'a CheckSpec>
pub fn resolve_checks<'a>( &self, available: &'a [CheckSpec], ) -> Vec<&'a CheckSpec>
Get the effective set of check names to run.
This resolves includes/excludes against the available checks.
Sourcepub fn should_ignore_path(&self, path: &Path) -> bool
pub fn should_ignore_path(&self, path: &Path) -> bool
Check if a file path should be ignored based on ignore_paths patterns.
Sourcepub fn load_from_file(path: &Path) -> Result<Self, ConfigError>
pub fn load_from_file(path: &Path) -> Result<Self, ConfigError>
Load configuration from a YAML file.
Sourcepub fn load_from_str(content: &str) -> Result<Self, ConfigError>
pub fn load_from_str(content: &str) -> Result<Self, ConfigError>
Load configuration from a YAML string.
Sourcepub fn load_from_default() -> Option<Self>
pub fn load_from_default() -> Option<Self>
Try to load config from default locations (.kube-linter.yaml, .kube-linter.yml).