Module context

Module context 

Lint context for Kubernetes objects.

The lint context holds all parsed Kubernetes objects and provides access to them during check execution.

Re-exports

pub use object::InvalidObject;
pub use object::K8sObject;
pub use object::Object;
pub use object::ObjectMetadata;

Modules

object
Kubernetes object wrappers for linting.

Structs

LintContextImpl
Default implementation of LintContext.

Traits

LintContext
A lint context provides access to all parsed Kubernetes objects.