pub struct PlatformSession {
pub project_id: Option<String>,
pub project_name: Option<String>,
pub org_id: Option<String>,
pub org_name: Option<String>,
pub environment_id: Option<String>,
pub environment_name: Option<String>,
pub last_updated: Option<DateTime<Utc>>,
}Expand description
Platform session state - tracks selected project, organization, and environment
This is a separate system from conversation persistence - it tracks which platform project/org/environment the user has selected for platform operations.
Fields
project_id: Option<String>Selected platform project UUID
project_name: Option<String>Human-readable project name
org_id: Option<String>Organization UUID
org_name: Option<String>Organization name
environment_id: Option<String>Selected environment UUID
environment_name: Option<String>Human-readable environment name
last_updated: Option<DateTime<Utc>>When the session was last updated
Implementations
Sourceimpl PlatformSession
impl PlatformSession
Sourcepub fn with_project(
project_id: String,
project_name: String,
org_id: String,
org_name: String,
) -> Self
pub fn with_project( project_id: String, project_name: String, org_id: String, org_name: String, ) -> Self
Creates a platform session with a selected project
Sourcepub fn with_environment(
project_id: String,
project_name: String,
org_id: String,
org_name: String,
environment_id: String,
environment_name: String,
) -> Self
pub fn with_environment( project_id: String, project_name: String, org_id: String, org_name: String, environment_id: String, environment_name: String, ) -> Self
Creates a platform session with a selected project and environment
Sourcepub fn clear_environment(&mut self)
pub fn clear_environment(&mut self)
Clears only the selected environment (keeps project)
Sourcepub fn is_project_selected(&self) -> bool
pub fn is_project_selected(&self) -> bool
Returns true if a project is currently selected
Sourcepub fn is_environment_selected(&self) -> bool
pub fn is_environment_selected(&self) -> bool
Returns true if an environment is currently selected
Sourcepub fn session_path() -> PathBuf
pub fn session_path() -> PathBuf
Returns the path to the platform session file
Location: ~/.syncable/platform-session.json
Sourcepub fn load() -> Result<Self>
pub fn load() -> Result<Self>
Load platform session from disk
Returns Default if the file doesn’t exist or can’t be parsed.
Sourcepub fn save(&self) -> Result<()>
pub fn save(&self) -> Result<()>
Save platform session to disk
Creates ~/.syncable/ directory if it doesn’t exist.
Sourcepub fn display_context(&self) -> String
pub fn display_context(&self) -> String
Returns a display string for the current context
Format: “[org/project/env]”, “[org/project]”, or “[no project selected]”