pub struct ServerState { /* private fields */ }Expand description
Shared state for the AG-UI server.
Implementations
Sourceimpl ServerState
impl ServerState
Sourcepub fn event_sender(&self) -> EventBridge
pub fn event_sender(&self) -> EventBridge
Gets the event sender for emitting events.
Sourcepub fn message_sender(&self) -> Sender<AgentMessage>
pub fn message_sender(&self) -> Sender<AgentMessage>
Gets the message sender for routing incoming messages.
Sourcepub async fn take_message_receiver(&self) -> Option<Receiver<AgentMessage>>
pub async fn take_message_receiver(&self) -> Option<Receiver<AgentMessage>>
Takes the message receiver (can only be called once).
This is used by the agent processor to receive messages from frontends. Returns None if the receiver has already been taken.