ServerState

Struct ServerState 

pub struct ServerState { /* private fields */ }
Shared state for the AG-UI server.

Implementations

Source

impl ServerState

pub fn new() -> Self

Creates new server state.

pub fn event_sender(&self) -> EventBridge

Gets the event sender for emitting events.

pub fn subscribe(&self) -> Receiver<Event<JsonValue>>

Subscribes to the event stream.

pub fn message_sender(&self) -> Sender<AgentMessage>

Gets the message sender for routing incoming messages.

pub async fn take_message_receiver(&self) -> Option<Receiver<AgentMessage>>

Takes the message receiver (can only be called once).

This is used by the agent processor to receive messages from frontends. Returns None if the receiver has already been taken.