pub async fn find_best_region(
client: &PlatformApiClient,
project_id: &str,
preferred_zone: Option<&str>,
) -> Option<DynamicCloudRegion>Expand description
Find the best region for a workload based on availability
Returns the region with the most available server types, preferring regions in the specified network zone.